[![Build Status](https://github.com/dbbs-lab/glia/actions/workflows/main.yml/badge.svg)](https://github.com/dbbs-lab/glia)
[![codecov](https://codecov.io/gh/dbbs-lab/glia/branch/main/graph/badge.svg)](https://codecov.io/gh/dbbs-lab/glia)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/nrn-glia/badge/?version=latest)](https://nmodl-glia.readthedocs.io/en/latest/)

# Glia: NMODL asset manager

View the online documentation at [https://nmodl-glia.readthedocs.io/en/latest/](https://nmodl-glia.readthedocs.io/en/latest/)